EnableCharacteristicNotificationCommand class

Init command to be performed on a device during the configuration state.

Implemented types

Constructors

EnableCharacteristicNotificationCommand({required String serviceUuid, required String charUuid})
const

Properties

charUuid → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid → String
final

Methods

execute({required IBleDevice device}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
undo({required IBleDevice device}) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited